# Retrace

#### Retrace your steps and try again.

---

[![PyPI Downloads][pypi-dl-image]][pypi-dl-link]
[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Build Status][travis-image]][travis-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Landscale Code Health][landscape-image]][landscape-link]

Retrace provides a configurable decorator which allows you to wrap Python
callables and retry them on errors or other specific conditions.

#### See the documentation at http://d0ugal.github.io/retrace/

[codecov-image]: http://codecov.io/github/d0ugal/retrace/coverage.svg?branch=master
[codecov-link]: http://codecov.io/github/d0ugal/retrace?branch=master
[landscape-image]: https://landscape.io/github/d0ugal/retrace/master/landscape.svg?style=flat-square
[landscape-link]: https://landscape.io/github/d0ugal/retrace/master
[pypi-dl-image]: https://img.shields.io/pypi/dm/retrace.png
[pypi-dl-link]: https://pypi.python.org/pypi/retrace
[pypi-v-image]: https://img.shields.io/pypi/v/retrace.png
[pypi-v-link]: https://pypi.python.org/pypi/retrace
[travis-image]: https://img.shields.io/travis/d0ugal/retrace/master.png
[travis-link]: https://travis-ci.org/d0ugal/retrace
